@@ -5,8 +5,10 @@
 
 from __future__ import print_function
 
+import os
 import subprocess
 import sys
+import tempfile
 
 SVN_NOT_FOUND = '''
 Mach could not download mozboot.
@@ -19,15 +21,21 @@ tree which contains mozboot.
 
 REPO = 'https://github.com/mozilla/gecko-dev/'
 
-def install_module(module, save_dir='mozboot'):
+def install_module(module, save_dir=None):
     print('Attempting to install mozboot...')
-    url = REPO + 'trunk/' + module
 
-    command = ['svn', 'export', url, save_dir]
+    url = REPO + 'trunk/' + module
+    command = ['svn', 'export', url, os.path.basename(module.rstrip(os.sep))]
+
+    if not save_dir:
+        save_dir = tempfile.mkdtemp()
+
     try:
-        subprocess.check_call(command)
+        subprocess.check_call(command, cwd=save_dir)
     except OSError:
         print(SVN_NOT_FOUND)
         sys.exit(1)
 
+    sys.path.insert(0, save_dir)
+
     return save_dir
